@@ -9,15 +9,16 @@
  *   See the file COPYING.LIB
  *
  */
- 
- 
+
+
 /*
  * $Id: br.c,v 1.4 2004-11-01 19:33:28 tigran Exp $
  */
- 
+
 #include <sys/stat.h>
 #include <sys/types.h>
-#include <dcap.h>
+
+#include "dcap.h"
 
 main(int argc, char *argv[])
 {
@@ -26,7 +27,7 @@ main(int argc, char *argv[])
 	off_t           size, tsize = 0, n;
 	char           *buf;
 	int             count;
-	
+
 	if(argc != 4) {
 		printf("Usage: %s <file> <buffersize> <count>\n", argv[0]);
 		exit(1);
