@@ -312,16 +312,11 @@ ssize_t dc_writev(int fd, const struct iovec *vector, int count) {
 	/* nothing wrong ... yet */
 	dc_errno = DEOK;
 
-#ifdef IOV_MAX
-	if( (count == 0) || (count > IOV_MAX) ) {
-#else
-	if(count == 0) {
-#endif
+	if( (count < 0 ) || (count > IOV_MAX) ) {
 		errno = EINVAL;
 		return -1;
 	}
 
-
 	node = get_vsp_node(fd);
 	if (node == NULL) {
 		/* we have not such file descriptor, so lets give a try to system */
