@@ -10,12 +10,12 @@
  *   See the file COPYING.LIB
  *
  */
- 
- 
+
+
 /*
  * $Id: system_io.c,v 1.54 2006-09-26 07:41:11 tigran Exp $
  */
- 
+
 #ifdef LIBC_SYSCALLS
 
 #include <stdio.h>
@@ -123,7 +123,7 @@ static ssize_t (*s_pwrite64)   (int, const void *, size_t, off64_t);
 static off64_t (*s_lseek64)    (int, off64_t, int);
 static int (*s_close)          (int);
 
-/* 
+/*
  * A version number is included in the x86 SVR4 stat interface
  * so that SVR3 binaries can be supported
  */
@@ -178,7 +178,12 @@ static int (*s_feof)(FILE *);
 static char * (*s_fgets)(char *, int, FILE *);
 static int (*s_fgetc)(FILE *);
 
-static void stat64to32(struct stat *st32, const struct stat64 *st64)
+static int initIfNeeded();
+static void stat64to32(struct stat *st32, const struct stat64 *st64);
+
+
+/* FIXME: stat64to32 is duplicated in dcap_stat.c */
+void stat64to32(struct stat *st32, const struct stat64 *st64)
 {
 	memset(st32, 0, sizeof(struct stat) );
 
@@ -197,14 +202,14 @@ static void stat64to32(struct stat *st32, const struct stat64 *st64)
 	st32->st_ctime = st64->st_ctime;
 }
 
-static int initIfNeeded()
+int initIfNeeded()
 {
 	union pointer_converter convert;
 	char *em;
 
 	sigset_t block_set;
-	
-	
+
+
 	/* we do not want to be interrupted */
 	sigemptyset(&block_set);
 	sigaddset(&block_set, SIGALRM);
@@ -212,10 +217,10 @@ static int initIfNeeded()
 
 	m_lock(&gLock);
 
-	if(handle != NULL) {		
+	if(handle != NULL) {
 		m_unlock(&gLock);
 /*		dc_debug(DC_TRACE, "System IO already initialized.");		*/
-		
+
 		/* restore signal handling */
 		sigprocmask(SIG_UNBLOCK, &block_set, NULL);
 		return 0;
@@ -227,26 +232,26 @@ static int initIfNeeded()
 	}
 	if( libname != NULL ) {
 		handle = dlopen( libname, RTLD_NOW | RTLD_GLOBAL);
-		if(handle == NULL) {		
+		if(handle == NULL) {
 			m_unlock(&gLock);
 /*			dc_debug(DC_ERROR, "Failed to initialize System IO: (%s).", dlerror()); */
 #if 0
 			perror(dlerror() );
 #endif
 			/* restore signal handling */
-			sigprocmask(SIG_UNBLOCK, &block_set, NULL); 
+			sigprocmask(SIG_UNBLOCK, &block_set, NULL);
 			return -1;
 		}
 	}
 	#ifdef RTLD_NEXT
 	else{
 		/* try to use other dynamic libraries to get requaried functions */
-		
+
 		handle = RTLD_NEXT;
 	}
 	#endif
 
-    
+
 	ASSIGN_FN( s_open,     convert, handle, OPEN_SYM);
 	ASSIGN_FN( s_read,     convert, handle, READ_SYM);
 	ASSIGN_FN( s_readv,    convert, handle, READV_SYM);
@@ -257,7 +262,7 @@ static int initIfNeeded()
 	ASSIGN_FN( s_pwrite,   convert, handle, PWRITE_SYM);
 	ASSIGN_FN( s_pwrite64, convert, handle, PWRITE64_SYM);
 	ASSIGN_FN( s_lseek64,  convert, handle, LSEEK64_SYM);
-	ASSIGN_FN( s_close,    convert, handle, CLOSE_SYM);		 
+	ASSIGN_FN( s_close,    convert, handle, CLOSE_SYM);
 	ASSIGN_FN( s_stat,     convert, handle, STAT64_SYM);
 	ASSIGN_FN( s_stat64,   convert, handle, STAT64_SYM);
 	ASSIGN_FN( s_lstat,    convert, handle, LSTAT_SYM);
@@ -303,19 +308,19 @@ static int initIfNeeded()
 	ASSIGN_FN( s_ferror,   convert, handle, "ferror");
 	ASSIGN_FN( s_fgets,    convert, handle, "fgets");
 	ASSIGN_FN( s_fgetc,    convert, handle, "fgetc");
-	
+
 	if( (s_open == NULL) || (s_read == NULL) ||
-		(s_pread == NULL) || (s_write == NULL) || 
+		(s_pread == NULL) || (s_write == NULL) ||
 		(s_pwrite == NULL) || (s_pread64 == NULL) || (s_pwrite64 == NULL) ||
 		(s_lseek64 == NULL) || (s_close == NULL) ||
-		(s_stat == NULL) || (s_fstat == NULL ) || (s_fsync == NULL) || 
-		(s_stat64 == NULL) || (s_fstat64 == NULL ) || 
-		(s_lstat == NULL) || (s_lstat64 == NULL ) || 
+		(s_stat == NULL) || (s_fstat == NULL ) || (s_fsync == NULL) ||
+		(s_stat64 == NULL) || (s_fstat64 == NULL ) ||
+		(s_lstat == NULL) || (s_lstat64 == NULL ) ||
 		(s_dup == NULL) || (s_opendir == NULL) || (s_closedir == NULL) ||
 		(s_readdir == NULL) || (s_readdir64 ==  NULL) ||
-		(s_telldir == NULL) || (s_seekdir == NULL) || 
-		(s_unlink == NULL ) || (s_rmdir == NULL ) || 
-		(s_mkdir == NULL ) || (s_chmod == NULL ) || (s_access == NULL )  || 
+		(s_telldir == NULL) || (s_seekdir == NULL) ||
+		(s_unlink == NULL ) || (s_rmdir == NULL ) ||
+		(s_mkdir == NULL ) || (s_chmod == NULL ) || (s_access == NULL )  ||
 #ifdef HAVE_ACL
 		(s_acl == NULL ) ||
 #endif /* HAVE_ACL */
@@ -324,15 +329,15 @@ static int initIfNeeded()
 #endif /* HAVE_FACL */
 
 		(s_chown == NULL ) ) {
-		
+
 		/* try to write error message it's possible */
 		if( s_write != NULL ) {
 			em = dlerror();
-			if(em != NULL ) {		
+			if(em != NULL ) {
 				s_write(2, em, strlen(em) );
 			}
 		}
-		
+
 /*		dc_debug(DC_ERROR, "Failed to initialize System IO: (%s).", dlerror()); */
 		dlclose(handle);
 		handle = NULL;
@@ -360,8 +365,8 @@ static int initIfNeeded()
 		fprintf(stderr, "readdir 0x%x\n", sReaddir);
 		fprintf(stderr, "readdir64 0x%x\n", sReaddir64);
 		fprintf(stderr, "closedir 0x%x\n", sClosedir);
-		fprintf(stderr, "seekdir 0x%x\n", sSeekdir);						
-		fprintf(stderr, "telldir 0x%x\n", sTelldir);		
+		fprintf(stderr, "seekdir 0x%x\n", sSeekdir);
+		fprintf(stderr, "telldir 0x%x\n", sTelldir);
 		fflush(stderr);
 #endif
 		/* restore signal handling */
@@ -369,14 +374,14 @@ static int initIfNeeded()
 
 		return -17;
 
-	
+
 	}
-	
+
 	m_unlock(&gLock);
 
 	/* restore signal handling */
-	sigprocmask(SIG_UNBLOCK, &block_set, NULL); 
-	
+	sigprocmask(SIG_UNBLOCK, &block_set, NULL);
+
 	return 0;
 
 }
@@ -447,10 +452,10 @@ int system_fstat( int fd, struct stat *buf)
 {
 	struct stat64 s;
 	int rc;
-	
-	if ( initIfNeeded() != 0 ) { 
+
+	if ( initIfNeeded() != 0 ) {
 		return -1;
-	} 
+	}
 
 	rc = s_fstat64(_STAT_VER, fd, &s);
 
@@ -474,10 +479,10 @@ int system_stat( const char *path, struct stat *buf)
 {
 	struct stat64 s;
 	int rc;
-	
-	if ( initIfNeeded() != 0 ) { 
+
+	if ( initIfNeeded() != 0 ) {
 		return -1;
-	} 
+	}
 
 	rc = s_stat64(_STAT_VER, path, &s);
 
@@ -492,7 +497,7 @@ int system_lstat( const char *path, struct stat *buf)
 	int rc;
 	if ( initIfNeeded() != 0 ) {
 		return -1;
-	} 
+	}
 
 	rc = s_lstat64(_STAT_VER, path, &s);
 
@@ -509,10 +514,10 @@ int system_fstat( int fd, struct stat *buf)
 {
 	struct stat64 s;
 	int rc;
-	
-	if ( initIfNeeded() != 0 ) { 
+
+	if ( initIfNeeded() != 0 ) {
 		return -1;
-	} 
+	}
 
 	rc = s_fstat64(fd, &s);
 
@@ -536,10 +541,10 @@ int system_stat( const char *path, struct stat *buf)
 {
 	struct stat64 s;
 	int rc;
-	
-	if ( initIfNeeded() != 0 ) { 
+
+	if ( initIfNeeded() != 0 ) {
 		return -1;
-	} 
+	}
 
 	rc = s_stat64(path, &s);
 
@@ -554,7 +559,7 @@ int system_lstat( const char *path, struct stat *buf)
 	int rc;
 	if ( initIfNeeded() != 0 ) {
 		return -1;
-	} 
+	}
 
 	rc = s_lstat64(path, &s);
 
